MapData class

the map data

each map have its own data, the data is accessible as read only, it can't be modify by the sdk

Constructors

MapData({required int id, required String style, required int minZoom, required int maxZoom, required BBox bounds, BBox? maxBounds, UseTags? useTags, required ActionButtons actionButtons})
MapData.fromMap(dynamic mapDataMap)
factory
MapData.singleton()
factory

Properties

actionButtons ActionButtons
final
bounds → BBox
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
maxBounds → BBox?
final
maxZoom int
final
minZoom int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style String
final
useTags UseTags?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited